@@ -169,7 +169,7 @@ Nevertheless, there's no shame in pinching a good idea when you see one...
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 6
+__ver_patch__ = 7
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -412,7 +412,7 @@ class RestartSuite(object):
             else:
                 raise
         except Exception:
-            exc_type, exc_value, exc_traceback = sys.exc_info()
+            exc_type, exc_value, traceback = sys.exc_info()
         while exc_value is not None:
             try:
                 self._invoke_handlers(exc_value)
